@@ -46,9 +46,10 @@ class GSPeerConnectionBroadcasterPiCaller:
         self.oncommand = oncommand
         self.setChannel = setChannel
 
-    def startSocket(self):
+    async def startSocket(self):
         self._logger.debug("start broadcast socket")
-        GSPeerConnectionBroadcasterPiSocketv2.create(self.sio, self.gsdbs, self.camera, self.oncommand, self.setChannel)
+        await GSPeerConnectionBroadcasterPiSocketv2.create(self.sio, self.gsdbs, self.camera, self.oncommand,
+                                                           self.setChannel)
 
     def getconnectionurl(self):
         connectURL = self.gsdbs.credentials["signalserver"]
@@ -309,15 +310,15 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         self.relay = None
 
         @self.sio.event
-        async def connect():
+        def connect():
             self._logger.info('connection established')
 
         @self.sio.event
-        async def wjoined(id):
-            await self.sio.emit("joined", self.sio.sid)
+        def wjoined(id):
+            self.sio.emit("joined", self.sio.sid)
 
         @self.sio.event
-        async def broadcaster(id, description):
+        def broadcaster(id, description):
 
             if len(self.rtconfiList) > 0:
                 pc = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
@@ -373,14 +374,14 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
             await pc.setLocalDescription(await pc.createOffer())
 
-            await self.sio.emit("watcher", {"target": description,
+            self.sio.emit("watcher", {"target": description,
                                             "id": id,
                                             "sdp": json.dumps(
                                                 {"type": pc.localDescription.type,
                                                  "sdp": pc.localDescription.sdp})})
 
         @self.sio.event
-        async def answer(id, description):
+        def answer(id, description):
 
             if id in self.peerConnections:
                 if self.peerConnections[id].signalingState != "stable":
@@ -391,14 +392,14 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                     await self.peerConnections[id].setRemoteDescription(answer)
 
         @self.sio.event
-        async def disconnectBroadcaster(id, desc):
+        def disconnectBroadcaster(id, desc):
             if id in self.peerConnections:
                 self._logger.info("Disconnected Peer")
                 await self.peerConnections[id].close()
                 self.peerConnections.pop(id, None)
 
         @self.sio.event
-        async def disconnect():
+        def disconnect():
             self._logger.info('disconnected from server')
 
         connectURL = ""
